@@ -3,7 +3,7 @@
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of 
+ *  published by the Free Software Foundation; either version 2 of
  *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -28,26 +28,23 @@
 #include <QSharedData>
 #include <QStandardPaths>
 
-
 class KCardThemePrivate : public QSharedData
 {
 public:
-    KCardThemePrivate( bool isValid,
-                       const QString & dirName,
-                       const QString & displayName,
-                       const QString & desktopFilePath,
-                       const QString & graphicsFilePath,
-                       const QSet<QString> & supportedFeatures,
-                       const QDateTime & lastModified )
-      : isValid( isValid ),
-        dirName( dirName ),
-        displayName( displayName ),
-        desktopFilePath( desktopFilePath ),
-        graphicsFilePath( graphicsFilePath ),
-        supportedFeatures( supportedFeatures ),
-        lastModified( lastModified )
-    {
-    };
+    KCardThemePrivate(bool isValid,
+                      const QString &dirName,
+                      const QString &displayName,
+                      const QString &desktopFilePath,
+                      const QString &graphicsFilePath,
+                      const QSet<QString> &supportedFeatures,
+                      const QDateTime &lastModified)
+        : isValid(isValid)
+        , dirName(dirName)
+        , displayName(displayName)
+        , desktopFilePath(desktopFilePath)
+        , graphicsFilePath(graphicsFilePath)
+        , supportedFeatures(supportedFeatures)
+        , lastModified(lastModified){};
 
     const bool isValid;
     const QString dirName;
@@ -58,56 +55,50 @@ public:
     const QDateTime lastModified;
 };
 
-
 QList<KCardTheme> KCardTheme::findAll()
 {
     QList<KCardTheme> result;
-    const QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory );
+    const QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory);
     for (const QString &index : indexFiles) {
         const QStringList entries = QDir(index).entryList(QDir::Dirs);
         for (const QString &d : entries) {
             QString indexFilePath = index + QLatin1Char('/') + d + QLatin1String("/index.desktop");
             if (QFile::exists(indexFilePath)) {
-                QString directoryName = QFileInfo( indexFilePath ).dir().dirName();
-                KCardTheme t( directoryName );
-                if ( t.isValid() )
+                QString directoryName = QFileInfo(indexFilePath).dir().dirName();
+                KCardTheme t(directoryName);
+                if (t.isValid())
                     result << t;
-
             }
         }
     }
     return result;
 }
 
-
-QList<KCardTheme> KCardTheme::findAllWithFeatures( const QSet<QString> & neededFeatures )
+QList<KCardTheme> KCardTheme::findAllWithFeatures(const QSet<QString> &neededFeatures)
 {
     QList<KCardTheme> result;
-    const QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory );
+    const QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory);
     for (const QString &index : indexFiles) {
         const QStringList entries = QDir(index).entryList(QDir::Dirs);
         for (const QString &d : entries) {
             QString indexFilePath = index + QLatin1Char('/') + d + QLatin1String("/index.desktop");
             if (QFile::exists(indexFilePath)) {
-                QString directoryName = QFileInfo( indexFilePath ).dir().dirName();
-                KCardTheme t( directoryName );
-                if ( t.isValid() && t.supportedFeatures().contains( neededFeatures ) )
+                QString directoryName = QFileInfo(indexFilePath).dir().dirName();
+                KCardTheme t(directoryName);
+                if (t.isValid() && t.supportedFeatures().contains(neededFeatures))
                     result << t;
-
             }
         }
     }
     return result;
 }
 
-
 KCardTheme::KCardTheme()
-  : d( nullptr )
+    : d(nullptr)
 {
 }
 
-
-KCardTheme::KCardTheme( const QString & dirName )
+KCardTheme::KCardTheme(const QString &dirName)
 {
     bool isValid = false;
     QString displayName;
@@ -116,30 +107,26 @@ KCardTheme::KCardTheme( const QString & dirName )
     QStringList supportedFeatures;
     QDateTime lastModified;
 
-    QString indexFilePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral( "carddecks/%1/index.desktop" ).arg( dirName ) );
-    if ( !indexFilePath.isEmpty() )
-    {
+    QString indexFilePath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks/%1/index.desktop").arg(dirName));
+    if (!indexFilePath.isEmpty()) {
         desktopFilePath = indexFilePath;
 
-        KConfig config( indexFilePath, KConfig::SimpleConfig );
-        if ( config.hasGroup( "KDE Backdeck" ) )
-        {
-            KConfigGroup configGroup = config.group( "KDE Backdeck" );
+        KConfig config(indexFilePath, KConfig::SimpleConfig);
+        if (config.hasGroup("KDE Backdeck")) {
+            KConfigGroup configGroup = config.group("KDE Backdeck");
 
-            displayName = configGroup.readEntry( "Name" );
+            displayName = configGroup.readEntry("Name");
 
-            supportedFeatures = configGroup.readEntry( "Features", QStringList() << QStringLiteral("AngloAmerican") << QStringLiteral("Backs1") );
+            supportedFeatures = configGroup.readEntry("Features", QStringList() << QStringLiteral("AngloAmerican") << QStringLiteral("Backs1"));
 
-            QString svgName = configGroup.readEntry( "SVG" );
-            if ( !svgName.isEmpty() )
-            {
-                QFileInfo indexFile( indexFilePath );
-                QFileInfo svgFile( indexFile.dir(), svgName );
+            QString svgName = configGroup.readEntry("SVG");
+            if (!svgName.isEmpty()) {
+                QFileInfo indexFile(indexFilePath);
+                QFileInfo svgFile(indexFile.dir(), svgName);
                 graphicsFilePath = svgFile.absoluteFilePath();
 
-                if ( svgFile.exists() )
-                {
-                    lastModified = qMax( svgFile.lastModified(), indexFile.lastModified() );
+                if (svgFile.exists()) {
+                    lastModified = qMax(svgFile.lastModified(), indexFile.lastModified());
                     isValid = true;
                 }
             }
@@ -147,84 +134,65 @@ KCardTheme::KCardTheme( const QString & dirName )
     }
 
     const QSet<QString> supportedFeaturesSet(supportedFeatures.cbegin(), supportedFeatures.cend());
-    d = new KCardThemePrivate( isValid,
-                               dirName,
-                               displayName,
-                               desktopFilePath,
-                               graphicsFilePath,
-                               supportedFeaturesSet,
-                               lastModified );
+    d = new KCardThemePrivate(isValid, dirName, displayName, desktopFilePath, graphicsFilePath, supportedFeaturesSet, lastModified);
 }
 
-
-KCardTheme::KCardTheme( const KCardTheme & other )
-  : d( other.d )
+KCardTheme::KCardTheme(const KCardTheme &other)
+    : d(other.d)
 {
 }
 
-
 KCardTheme::~KCardTheme()
 {
 }
 
-
-KCardTheme & KCardTheme::operator=( const KCardTheme & other )
+KCardTheme &KCardTheme::operator=(const KCardTheme &other)
 {
     d = other.d;
     return *this;
 }
 
-
 bool KCardTheme::isValid() const
 {
     return d && d->isValid;
 }
 
-
 QString KCardTheme::dirName() const
 {
     return d ? d->dirName : QString();
 }
 
-
 QString KCardTheme::displayName() const
 {
     return d ? d->displayName : QString();
 }
 
-
 QString KCardTheme::desktopFilePath() const
 {
     return d ? d->desktopFilePath : QString();
 }
 
-
 QString KCardTheme::graphicsFilePath() const
 {
     return d ? d->graphicsFilePath : QString();
 }
 
-
 QDateTime KCardTheme::lastModified() const
 {
     return d ? d->lastModified : QDateTime();
 }
 
-
 QSet<QString> KCardTheme::supportedFeatures() const
 {
     return d ? d->supportedFeatures : QSet<QString>();
 }
 
-
-bool KCardTheme::operator==( const KCardTheme &theme ) const
+bool KCardTheme::operator==(const KCardTheme &theme) const
 {
     return dirName() == theme.dirName();
 }
 
-
-bool KCardTheme::operator!=( const KCardTheme &theme ) const
+bool KCardTheme::operator!=(const KCardTheme &theme) const
 {
-    return !operator==( theme );
+    return !operator==(theme);
 }
-
