@@ -3,7 +3,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of 
+ * published by the Free Software Foundation; either version 2 of
  * the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -22,101 +22,83 @@
 // Qt
 #include <QPainter>
 
-
 namespace
 {
-    const qreal textToBoxSizeRatio = 0.8;
-    const int MessageBoxMinimumFontSize = 5;
-    const int maximumFontSize = 36;
+const qreal textToBoxSizeRatio = 0.8;
+const int MessageBoxMinimumFontSize = 5;
+const int maximumFontSize = 36;
 }
 
-
 MessageBox::MessageBox()
-  : KGameRenderedItem( Renderer::self(), QStringLiteral("message_frame") ),
-    m_fontCached( false )
+    : KGameRenderedItem(Renderer::self(), QStringLiteral("message_frame"))
+    , m_fontCached(false)
 {
-
 }
 
-
-void MessageBox::setMessage( const QString & message )
+void MessageBox::setMessage(const QString &message)
 {
-    if ( m_message != message )
-    {
+    if (m_message != message) {
         m_message = message;
         m_fontCached = false;
         update();
     }
 }
 
-
 QString MessageBox::message() const
 {
     return m_message;
 }
 
-
-void MessageBox::setSize( const QSize & size )
+void MessageBox::setSize(const QSize &size)
 {
-    if ( size != renderSize() )
-    {
-        setRenderSize( size );
+    if (size != renderSize()) {
+        setRenderSize(size);
         m_fontCached = false;
     }
 }
 
-
 QSize MessageBox::size() const
 {
     return renderSize();
 }
 
-
-void MessageBox::paint( QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget )
+void MessageBox::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
     QRect rect = pixmap().rect();
     rect.setWidth(rect.width() / pixmap().devicePixelRatio());
     rect.setHeight(rect.height() / pixmap().devicePixelRatio());
 
-    if ( rect.isEmpty() )
+    if (rect.isEmpty())
         return;
 
-    KGameRenderedItem::paint( painter, option, widget );
+    KGameRenderedItem::paint(painter, option, widget);
 
-    painter->setFont( m_font );
+    painter->setFont(m_font);
 
-    if ( !m_fontCached )
-    {
+    if (!m_fontCached) {
         int availableWidth = rect.width() * textToBoxSizeRatio;
         int availableHeight = rect.height() * textToBoxSizeRatio;
         int size = maximumFontSize;
 
         QFont f = painter->font();
-        f.setPointSize( size );
-        painter->setFont( f );
-        do
-        {
-            QRect br = painter->boundingRect( rect, Qt::AlignLeft | Qt::AlignTop, m_message );
-            if ( br.width() < availableWidth && br.height() < availableHeight )
+        f.setPointSize(size);
+        painter->setFont(f);
+        do {
+            QRect br = painter->boundingRect(rect, Qt::AlignLeft | Qt::AlignTop, m_message);
+            if (br.width() < availableWidth && br.height() < availableHeight)
                 break;
 
-            size = qBound( MessageBoxMinimumFontSize,
-                           qMin( size * availableWidth / br.width(),
-                                 size * availableHeight / br.height() ),
-                           size - 1 );
+            size = qBound(MessageBoxMinimumFontSize, qMin(size * availableWidth / br.width(), size * availableHeight / br.height()), size - 1);
 
             QFont f = painter->font();
-            f.setPointSize( size );
-            painter->setFont( f );
-        }
-        while ( size > MessageBoxMinimumFontSize );
+            f.setPointSize(size);
+            painter->setFont(f);
+        } while (size > MessageBoxMinimumFontSize);
 
         m_font = painter->font();
         m_fontCached = true;
     }
 
-    painter->setPen( Renderer::self()->colorOfElement( QStringLiteral("message_text_color") ) );
-    painter->drawText( rect, Qt::AlignCenter, m_message );
+    painter->setPen(Renderer::self()->colorOfElement(QStringLiteral("message_text_color")));
+    painter->drawText(rect, Qt::AlignCenter, m_message);
 }
-
-
